@@ -48,6 +48,8 @@ from .util import (
 )
 from .types import (
     BlobInit,
+    BlobOwner,
+    CopyBlob,
     CSVBlobResponse,
     CSVList,
     CSVOp,
@@ -97,7 +99,7 @@ else:
     WVD = weakref.WeakValueDictionary
 
 
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 # FIXME: async calls, documentation, auth, summary – time it took etc.
 
 
@@ -560,7 +562,7 @@ class XYMEClient:
         if dest_id is not None:
             args["dest"] = dest_id
         return cast(PipelineDupResponse, self._request_json(
-            METHOD_POST, "/pipeline_dup", args, capture_err=False))["pipeline"]
+            METHOD_POST, "/pipeline_dup", args, capture_err=True))["pipeline"]
 
     def set_pipeline(
             self,
@@ -669,8 +671,8 @@ class XYMEClient:
 
     def check_queue_stats(
             self,
-            pipeline: Optional[str],
-            minimal: bool) -> Union[
+            pipeline: Optional[str] = None,
+            minimal: bool = False) -> Union[
                 MinimalQueueStatsResponse, QueueStatsResponse]:
         if minimal:
             return cast(MinimalQueueStatsResponse, self._request_json(
@@ -1696,6 +1698,46 @@ class BlobHandle:
     def as_str(self) -> str:
         return f"{self.get_uri()}"
 
+    def set_owner(self, new_owner: str) -> str:
+        if self.is_full():
+            raise ValueError(f"URI must not be full: {self}")
+        pipe = self.get_pipeline()
+        res = cast(BlobOwner, self._client._request_json(
+            METHOD_PUT, "/blob_owner", {
+                "pipeline": pipe.get_id(),
+                "blob": self._uri,
+                "owner": new_owner,
+            }, capture_err=False))
+        return res["owner"]
+
+    def get_owner(self) -> str:
+        if self.is_full():
+            raise ValueError(f"URI must not be full: {self}")
+        pipe = self.get_pipeline()
+        res = cast(BlobOwner, self._client._request_json(
+            METHOD_GET, "/blob_owner", {
+                "pipeline": pipe.get_id(),
+                "blob": self._uri,
+            }, capture_err=False))
+        return res["owner"]
+
+    def copy_to(
+            self,
+            to_uri: str,
+            new_owner: Optional[str] = None) -> 'BlobHandle':
+        if self.is_full():
+            raise ValueError(f"URI must not be full: {self}")
+        pipe = self.get_pipeline()
+        res = cast(CopyBlob, self._client._request_json(
+            METHOD_POST, "/copy_blob", {
+                "pipeline": pipe.get_id(),
+                "from_uri": self._uri,
+                "owner": new_owner,
+                "to_uri": to_uri,
+            }, capture_err=False))
+        return BlobHandle(
+            self._client, res["new_uri"], is_full=False, pipeline=pipe)
+
     def download_zip(self, to_path: Optional[str]) -> Optional[io.BytesIO]:
         if self.is_full():
             raise ValueError(f"URI must not be full: {self}")
@@ -1711,18 +1753,12 @@ class BlobHandle:
         return None
 
     def upload_zip(
-            self,
-            from_path: Optional[str],
-            from_io: Optional[io.BytesIO]) -> List['BlobHandle']:
-        if from_path is not None and from_io is not None:
-            raise ValueError("cannot have both from_path and from_io")
-        if from_io is not None:
-            zip_stream = from_io
-        elif from_path is not None:
-            with open(from_path, "rb") as fin:
+            self, source: Union[str, io.BytesIO]) -> List['BlobHandle']:
+        if isinstance(source, str) or not hasattr(source, "read"):
+            with open(f"{source}", "rb") as fin:
                 zip_stream = io.BytesIO(fin.read())
         else:
-            raise ValueError("from_path and from_io cannot be both None")
+            zip_stream = source
 
         resp = self._client._request_json(
             METHOD_FILE, "/upload_zip", {
@@ -1730,7 +1766,7 @@ class BlobHandle:
                 "pipeline": self.get_pipeline().get_id(),
             }, files={
                 "file": zip_stream,
-            }, capture_err=False)
+            }, capture_err=True)
         return [
             BlobHandle(
                 self._client,
