@@ -204,6 +204,12 @@ PutNodeBlob = TypedDict('PutNodeBlob', {
     "key": str,
     "new_uri": str,
 })
+BlobOwner = TypedDict('BlobOwner', {
+    "owner": str,
+})
+CopyBlob = TypedDict('CopyBlob', {
+    "new_uri": str,
+})
 QueueStatsResponse = TypedDict('QueueStatsResponse', {
     "active": int,
     "error": int,
